use game::*;
use bitboard::*;
use movegen::*;

fn value_castling_rights(game: &Game, side: Side) -> i32 {
    let mut val: i32 = 0;

    for i in 0..2 {
        if game.castling_rights[i] { val += 5; }
    }
    for i in 2..4 {
        if game.castling_rights[i] { val -= 5; }
    }
    
    if side == BLACK {
        return -val;
    }
    else {
        return val;
    }
}

fn side_value(game: &Game, side: Side) -> u32 {
    game.get_piece(PAWN, side).count_ones() * 100
    + game.get_piece(KNIGHT, side).count_ones() * 300
    + game.get_piece(BISHOP, side).count_ones() * 301
    + game.get_piece(ROOK, side).count_ones() * 400
    + game.get_piece(QUEEN, side).count_ones() * 600
    + game.get_piece(KING, side).count_ones() * 100000
}

pub fn evaluate(game: &Game) -> i32 {
    return side_value(game, game.turn) as i32 - side_value(game, !game.turn) as i32 + value_castling_rights(game, game.turn);
}
